<div id="attempt-{{aid}}" class="card {{active}}">
    <h3 class='card-header'>Attempt {{aid}} {{status_icon}}</h3>
    <hr class="dashed"/>
    <div class="info-block duration">
        🕑 Duration: <span>{{duration}}s</span>
    </div>

<!--    <div class="info-block error">-->
<!--        💥 Error:-->
<!--        <pre>{{error}}</pre>-->
<!--    </div>-->

<!--    <div class="info-block url">-->
<!--        🌏 URL: <a href="{{url}}" target="_blank">{{url}}</a>-->
<!--    </div>-->
    <!-- Artifacts Block -->
<!--    <div class="info-block artifacts">-->
<!--        <b>Artifacts</b><br/>-->
<!--        {{screenshot}} <span>Screenshot</span><br/>-->
<!--        {{video}} <span>Video</span><br/>-->
<!--        {{trace}} <span>Trace</span>-->
<!--    </div>-->

    <!-- Failure Panel Button -->
    {{view_failure_panel}}

    <div id="panel-{{aid}}" class="panel">
        {{failure_panel_html}}
    </div>
</div>