<div class="failure-panel retry-style">
    <h4>❌ Failure Panel (Attempt{{attempt}}) </h4>

    <div class="section">
        <details>
            <summary><b>🔗 Page URL</b></summary>
            <pre>{{page_url}}</pre>
        </details>
    </div>

    <div class="section">
        <details>
            <summary><b>🧯 Browser Console Errors</b></summary>
            <pre>{{console_pretty}}</pre>
        </details>
    </div>

    <div class="section">
        <details>
            <summary><b>❌ Test Failure Errors</b></summary>
            <pre>{{test_failure_info}}</pre>
        </details>
    </div>

    <div class="section">
        <details>
            <summary><b>📸 Screenshot</b></summary>
            <img src="data:image/png;base64,{{screenshot_base64}}"/>
        </details>
    </div>

    <div class="section">
        <details>
            <summary><b>🎥 Video</b></summary>
            <p class="hint">
                See Tear down / context attachment: <b>📎 Video</b>
            </p>
        </details>
    </div>
    <div class="section trace-block">
        {{trace_block}}
      </div>
</div>