<details>
  <summary><b>🧭 Trace</b></summary>
  <p class="hint">
    1️⃣ Click Tear down / context attachment：<b>📎 Playwright-Trace.zip</b><br/>
    2️⃣ Download <b>Playwright-Trace.zip</b><br/>
    3️⃣ Run in terminal:
  </p>

  <pre id="trace-cmd" class="trace-cmd" style="display:none;">npx playwright show-trace Playwright-Trace.zip</pre>

  <button
    type="button"
    class="copy-btn"
    onclick="copyTraceCmd(this);return false;">
    📋 Copy show-trace Command
  </button>
</details>