<!DOCTYPE html>
<html>
<head>
<style>
/* css-placeholder-start */
    {{css}}
/* css-placeholder-end */
</style>
<script>
    {{js}}
</script>
</head>

<body>
<h2>🔁 Attempt Summary</h2>
{{attempt_header}}
<!--{{attempt_chain}}-->
<div class="retry-insight"><h3>🧠 Retry Insight</h3>{{retry_insight_html}}</div>
<div class="attempt-diff"><h3>🔍 Attempt Diff Analysis</h3>{{attempt_diff}}</div>
<div class="tabs">{{tabs}}</div>
{{cards}}
</body>
</html>